@@ -1,10 +1,10 @@
-#' Function to conduct enrichment analysis given the input data and the ontology in query
+#' Function to conduct ontology enrichment analysis given a group of domains
 #'
-#' \code{dcEnrichment} is supposed to conduct enrichment analysis given the input data and the ontology in query. It returns an object of class "eTerm". Enrichment analysis is based on either Fisher's exact test or Hypergeometric test. The test can respect the hierarchy of the ontology.
+#' \code{dcEnrichment} is supposed to conduct enrichment analysis for an input group of domains using a specified ontology. It returns an object of S4 class "Eoutput". Enrichment analysis is based on either Fisher's exact test or Hypergeometric test. The test can respect the hierarchy of the ontology.
 #'
 #' @param data an input vector. It contains id for a list of domains, for example, sunids for SCOP domains
-#' @param domain the domain identity. It can be one of 'SCOP.sf' for SCOP superfamilies
-#' @param ontology the ontology supported currently. It can be "GOBP" for Gene Ontology Biological Process, "GOMF" for Gene Ontology Molecular Function, "GOCC" for Gene Ontology Cellular Component. For details on the eligibility for pairs of input domain and ontology, please refer to the online Documentations at \url{http://supfam.org/dcGOR/docs.html}
+#' @param domain the domain identity. It can be one of 'SCOP.sf' for SCOP superfamilies, 'SCOP.fa' for SCOP families
+#' @param ontology the ontology identity. It can be "GOBP" for Gene Ontology Biological Process, "GOMF" for Gene Ontology Molecular Function, "GOCC" for Gene Ontology Cellular Component, "DO" for Disease Ontology, "HPPA" for Human Phenotype Phenotypic Abnormality, "HPMI" for Human Phenotype Mode of Inheritance, "HPON" for Human Phenotype ONset and clinical course, "MP" for Mammalian Phenotype, "EC" for Enzyme Commission, "KW" for UniProtKB KeyWords, "UP" for UniProtKB UniPathway. For details on the eligibility for pairs of input domain and ontology, please refer to the online Documentations at \url{http://supfam.org/dcGOR/docs.html}
 #' @param sizeRange the minimum and maximum size of members of each term in consideration. By default, it sets to a minimum of 10 but no more than 1000
 #' @param min.overlap the minimum number of overlaps. Only those terms that overlap with input data at least min.overlap (3 domains by default) will be processed
 #' @param which_distance which distance of terms in the ontology is used to restrict terms in consideration. By default, it sets to 'NULL' to consider all distances
@@ -16,8 +16,10 @@
 #' @param verbose logical to indicate whether the messages will be displayed in the screen. By default, it sets to TRUE for display
 #' @param RData.location the characters to tell the location of built-in RData files. By default, it remotely locates at "http://supfam.org/dnet/data" or "https://github.com/hfang-bristol/dcGOR/data". For the user equipped with fast internet connection, this option can be just left as default. But it is always advisable to download these files locally. Especially when the user needs to run this function many times, there is no need to ask the function to remotely download every time (also it will unnecessarily increase the runtime). For examples, these files (as a whole or part of them) can be first downloaded into your current working directory, and then set this option as: \eqn{RData.location="."}. If RData to load is already part of package itself, this parameter can be ignored (since this function will try to load it via function \code{data} first)
 #' @return 
-#' an object of class "eTerm", a list with following components:
+#' an object of S4 class \code{\link{Eoutput}}, with following slots:
 #' \itemize{
+#'  \item{\code{domain}: a character specifying the domain identity}
+#'  \item{\code{ontology}: a character specifying the ontology used}
 #'  \item{\code{term_info}: a matrix of nTerm X 5 containing term information, where nTerm is the number of terms in consideration, and the 5 columns are "term_id" (i.e. "Term ID"), "term_name" (i.e. "Term Name"), "namespace" (i.e. "Term Namespace"), "distance" (i.e. "Term Distance") and "IC" (i.e. "Information Content for the term based on annotation frequency by it")}
 #'  \item{\code{anno}: a list of terms, each storing annotated domain members. Always, terms are identified by "term_id" and domain members identified by their ids (e.g. sunids for SCOP domains)}
 #'  \item{\code{data}: a vector containing input data in consideration. It is not always the same as the input data as only those mappable are retained}
@@ -25,7 +27,6 @@
 #'  \item{\code{zscore}: a vector containing z-scores}
 #'  \item{\code{pvalue}: a vector containing p-values}
 #'  \item{\code{adjp}: a vector containing adjusted p-values. It is the p value but after being adjusted for multiple comparisons}
-#'  \item{\code{call}: the call that produced this result}
 #' }
 #' @note The interpretation of the algorithms used to account for the hierarchy of the ontology is:
 #' \itemize{
@@ -37,7 +38,7 @@
 #' }
 #' @export
 #' @importFrom dnet dDAGinduce visDAG dDAGlevel dDAGroot
-#' @seealso \code{\link{dcRDataLoader}}, \code{\link{dcDAGannotate}}
+#' @seealso \code{\link{dcRDataLoader}}, \code{\link{dcDAGannotate}}, \code{\link{Eoutput-class}}, \code{\link{visEnrichment}}, \code{\link{dcConverter}}
 #' @include dcEnrichment.r
 #' @examples
 #' \dontrun{
@@ -46,24 +47,19 @@
 #' # randomly select 20 domains
 #' data <- sample(rowNames(SCOP.sf), 20)
 #' 
-#' # 2) perform enrichment analysis
-#' eTerm <- dcEnrichment(data, domain="SCOP.sf", ontology="GOMF")
+#' # 2) perform enrichment analysis, producing an object of S4 class 'Eoutput'
+#' eoutput <- dcEnrichment(data, domain="SCOP.sf", ontology="GOMF")
+#' eoutput
 #'
-#' # 3) visualise the top significant terms in the ontology hierarchy
-#' # load obo.GOMF (as 'igraph' object)
-#' g <- dcRDataLoader('obo.GOMF')
-#' # focus the top 5 enriched terms
-#' nodes_query <- names(sort(eTerm$adjp)[1:5])
-#' nodes.highlight <- rep("red", length(nodes_query))
-#' names(nodes.highlight) <- nodes_query
-#' subg <- dnet::dDAGinduce(g, nodes_query)
-#' # color-code terms according to the adjust p-values (taking the form of 10-based negative logarithm)
-#' dnet::visDAG(g=subg, data=-1*log10(eTerm$adjp[V(subg)$name]), node.info="both", zlim=c(0,2), node.attrs=list(color=nodes.highlight))
-#' # color-code terms according to the z-scores
-#' dnet::visDAG(g=subg, data=eTerm$zscore[V(subg)$name], node.info="both", colormap="darkblue-white-darkorange", node.attrs=list(color=nodes.highlight))
+#' # 3) view the top 10 significance terms 
+#' view(eoutput, top_num=10, sortBy="pvalue", details=TRUE)
+#'
+#' # 4) visualise the top 10 significant terms in the ontology hierarchy
+#' # color-coded according to 10-based negative logarithm of adjusted p-values (adjp)
+#' visEnrichment(eoutput)
 #' }
 
-dcEnrichment <- function(data, domain=c("SCOP.sf"), ontology=c("GOBP","GOMF","GOCC"), sizeRange=c(10,1000), min.overlap=3, which_distance=NULL, test=c("HypergeoTest","FisherTest","BinomialTest"), p.adjust.method=c("BH", "BY", "bonferroni", "holm", "hochberg", "hommel"), ontology.algorithm=c("none","pc","elim","lea"), elim.pvalue=1e-2, lea.depth=2, verbose=T, RData.location="http://supfam.org/dcGOR/data")
+dcEnrichment <- function(data, domain=c("SCOP.sf","SCOP.fa"), ontology=c("GOBP","GOMF","GOCC","DO","HPPA","HPMI","HPON","MP","EC","KW","UP"), sizeRange=c(10,1000), min.overlap=3, which_distance=NULL, test=c("HypergeoTest","FisherTest","BinomialTest"), p.adjust.method=c("BH", "BY", "bonferroni", "holm", "hochberg", "hommel"), ontology.algorithm=c("none","pc","elim","lea"), elim.pvalue=1e-2, lea.depth=2, verbose=T, RData.location="http://supfam.org/dcGOR/data")
 {
     startT <- Sys.time()
     message(paste(c("Start at ",as.character(startT)), collapse=""), appendLF=T)
@@ -90,7 +86,10 @@ dcEnrichment <- function(data, domain=c("SCOP.sf"), ontology=c("GOBP","GOMF","GO
 
     #########
     ## load ontology information
-    g <- dcRDataLoader(paste('obo.', ontology, sep=''), RData.location=RData.location)
+    g <- dcRDataLoader(paste('onto.', ontology, sep=''), RData.location=RData.location)
+    if(class(g)=="Onto"){
+        g <- dcConverter(g, from='Onto', to='igraph', verbose=F)
+    }
     
     #########
     ## load domain information
@@ -619,16 +618,17 @@ dcEnrichment <- function(data, domain=c("SCOP.sf"), ontology=c("GOBP","GOMF","GO
     names(annotations) <- V(dag)$term_id
     annotations <- annotations[names(gs)]
     
-    eTerm <- list(term_info= set_info,
-                  anno     = annotations,
-                  data     = data,
-                  overlap  = overlaps,
-                  zscore   = zscores,
-                  pvalue   = pvals,
-                  adjp     = adjpvals,
-                  call     = match.call()
+    eoutput <- new("Eoutput",
+                    domain    = domain,
+                    ontology  = ontology,
+                    term_info = set_info,
+                    anno      = annotations,
+                    data      = data,
+                    overlap   = overlaps,
+                    zscore    = zscores,
+                    pvalue    = pvals,
+                    adjp      = adjpvals
                  )
-    class(eTerm) <- "eTerm"
-    
-    invisible(eTerm)
+
+    invisible(eoutput)
 }
\ No newline at end of file
